@@ -8,7 +8,7 @@ use Class::Data::Inheritable;
 use base qw(Class::Data::Inheritable);
 
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 
 use DBI;
@@ -32,6 +32,8 @@ Similarly, if data is sent from a web application, the present implementation ma
 
 Some methods to access data will be implemented on an ad hoc basis, notably C<timestamp()>-methods, that will be important in determining the validity of cached data. 
 
+As of 0.05_1, there are also "Plural" subclasses. Sometimes you might want to retrieve more than one object from the data store, and do stuff on these objects as a whole. Furthermore, the load methods used to retrieve multiple objects may be optimized. This a conceptual change, and it'll take some time before it is being used in all parts of TABOO. 
+
 
 
 =head2 Methods
@@ -46,7 +48,6 @@ The constructor of this class. Rarely used.
 
 sub new {
     my $that  = shift;
-    my $username = shift;
     my $class = ref($that) || $that;
     my $self = {
 		ONFILE => undef,
@@ -58,35 +59,86 @@ sub new {
     return $self;
 }
 
-=item C<load($key)>
 
-Will load and populate the data structure of an instance with the data from a the data source, given a key in the string C<$key>. 
+=item C<load(what => fields, limit => {key => value, [...]})>
+
+Will load and populate the data structure of an object with the data
+from a data store. It uses named parameters, the first C<what> is used
+to determine which fields to retrieve. It is a string consisting of a
+commaseparated list of fields, as specified in the data store. The
+C<limit> argument is to be used to determine which records to
+retrieve, and must be used to identify a record uniquely. It is itself
+a reference to a hash, containing data store field values as keys and
+values are corresponding values to retrieve. These will be combined by
+logical AND.
+
 
 =cut
 
 sub load {
-    my $self = shift;
-    my $dbkey = shift;
+  my ($self, %args) = @_;
+  my $data = $self->_load(%args);
+  if ($data) {
+    ${$self}{'ONFILE'} = 1;
+  }
+  foreach my $key (keys(%{$data})) {
+    ${$self}{$key} = ${$data}{$key}; 
+  }
+  return $self;
+}
+
+
+=item C<_load(what => fields, limit => {key => value, [...]})>
+
+As the underscore implies this is B<for internal use only>! It is
+intended to do the hard work for this class and its subclasses. It returns a hashref of the data from the datastore.
+
+
+See the documentation for the C<load> method for the details on the parameters.
+
+=cut
+
+sub _load {
+    my ($self, %args) = @_;
+    my $what = $args{'what'};
+    my %arg =  %{$args{'limit'}};
     my $dbh = DBI->connect($self->dbstring(), 
 			   $self->dbuser(), 
 			   $self->dbpasswd(),  
-			   { PrintError => 0,
-			     RaiseError => 0,
-			     HandleError => Exception::Class::DBI->handler
+			   { PrintError => 1,
+			     RaiseError => 0 # ,
+			    # HandleError => Exception::Class::DBI->handler
 			     });
-    # just get the data, the subclass should give of the selectquery.
-    my $sth = $dbh->prepare($self->selectquery());
-    $sth->execute($dbkey);
-    my $data = $sth->fetchrow_hashref;
-    if ($data) {
-      ${$self}{'ONFILE'} = 1;
+    # The subclass should give the dbfrom.
+    my $query = "SELECT " . $what . " FROM " . $self->dbfrom() . " WHERE ";
+    my $i=0;
+    my $nothing=1;
+    my @keys = keys(%arg);
+    foreach my $key (@keys) {
+      $i++;
+      next unless ($arg{$key});
+      $nothing = 0;
+      $query .= $key . "=?";
+      if ($i <= $#keys) {
+	$query .= " AND ";
+      }
     }
-    foreach my $key (keys(%{$data})) {
-      ${$self}{$key} = ${$data}{$key}; 
+#    warn $query;
+    if ($nothing) {
+      # Then, none of the fields were actually sent with a value, so
+      # load won't return anything sensible...
+      return undef;
     }
-    $sth->finish;
-    $dbh->disconnect;
-    return $self;
+    my $sth = $dbh->prepare($query);
+    $i=1;
+#    warn Dumper(%arg);
+    foreach my $key (@keys) {
+      $sth->bind_param($i, $arg{$key});
+      $i++;
+    }
+    $sth->execute();
+
+    return $sth->fetchrow_hashref;
 }
 
 =item C<write_xml($doc, $parent)>
@@ -135,26 +187,23 @@ sub write_xml {
 	  $element->appendChild($text);
 	  $topel->appendChild($element);
         }
-      } else {
-#	$writer->emptyTag($key);
       }
     }
-#    $writer->endTag($self->xmlelement());
     return $doc;
 }
 
-=item C<apache_request_data(\%args)>
+=item C<populate(\%args)>
 
-This method takes as argument a reference to the args hash of a L<Apache::Request> object. Note that in a request, the Request object is available as C<$r>, so you may create this hash by 
+This method takes as argument a reference to a hash and will populate the data object by adding any data from a key having the same name as is used in the data storage. Fields that are not specified by the data object or that has uppercase letters are ignored. 
+
+It may be used to insert data from an L<Apache::Request> object by first noting that in a HTTP request, the Request object is available as C<$r>, so you may create the hash to hand to this method by 
 
     my %args = $r->args;
 
-It will populate the data object by adding any data from a parameter having the same name as is used in the data storage. Fields that are not specified by the data object or that has uppercase letters are ignored. 
-
 =cut
 
 
-sub apache_request_data {
+sub populate {
     my $self = shift;
     my $args = shift;
     foreach my $key (keys(%{$self})) {
@@ -191,7 +240,7 @@ sub apache_request_changed {
 
 This is a generic save method, that will write a new record to the data store, or update an old one. It may have to be subclassed for certain classes. It takes an optional argument C<$olddbkey>, which is the primary key of an existing record in the data store. You may supply this in the case if you want to update the record with a new key. In that case, you'd better be sure it actually exists, because the method will trust you do. 
 
-It is not yet a very rigorous implementation: It may well fail badly if it is given something with a reference to other Data objects, which is the case if you have a full story with all comments (see C<_addinfo> below). Or it may cope. Only time will tell! Expect to see funny warnings in your logs if you try.
+It is not yet a very rigorous implementation: It may well fail badly if it is given something with a reference to other Data objects, which is the case if you have a full story with all comments. Or it may cope. Only time will tell! Expect to see funny warnings in your logs if you try.
 
 
 =cut
@@ -260,7 +309,6 @@ Checks if a record with the present object's identifier is allready present in t
 
 =cut
 
-#'
 
 sub stored {
   my $self = shift;
@@ -276,14 +324,27 @@ sub stored {
   ${$self}{'ONFILE'} = $check;
   return $check;
 }
+
+
+=item C<onfile>
+
+Method to set a flag to indicate that the record is in the data store.
+
+=cut
+
   
+sub onfile {
+  my $self = shift;
+  ${$self}{'ONFILE'} = 1;
+  return $self;
+}
+
 =item C<xmlelement($string)>
 
 This method is I<intended> for internal use, but if you can use it without shooting somebody in the foot (including yourself), fine by me... It sets the root element that will enclose an object's data to C<$string>.
 
 =cut
 
-#' 
 
 sub xmlelement {
   my $self = shift;
@@ -310,35 +371,8 @@ sub xmlns {
 }
 
 
-
-=item C<_addinfo($add, $this, $that)>
-
-B<This method is for use by subclasses only.> It can be used by methods like C<adduserinfo()>, and will be used to replace a field (C<$this>) with another field (C<$that>) containing a reference to a different class that will be added, C<$add>. 
-
 =back
 
-=cut
-
-sub _addinfo {
-    my $self = shift;
-    my $add = shift;
-    my $this = shift;
-    my $that = shift;
-    if (${$self}{$this}) {
-      if (ref($add) eq 'AxKit::App::TABOO::Data::User') {
-	$add->load_name(${$self}{$this});
-      } else {
-	$add->load(${$self}{$this});
-      }
-      ${$self}{$that} = \$add;
-    } else {
-      carp $this . " had no value to replace.";
-    }
-    return $self;
-}
-
-
-
 =head2 Class Data Methods
 
 
@@ -363,9 +397,6 @@ The password to be passed to the DBI constructor. Currently defaults to an empty
 
 =cut
 
-#=item C<selectquery($string)>
-#
-#The load method of the present class will use this string as a SQL statement. This is a relatively simple way for subclasses to use the load method rather than implement their own. It can be used in the cases where the query is specific to the class rather than the specific instances. I<It is intended for use by subclasses only.>
 
 #=item C<elementorder($string)>
 
@@ -376,7 +407,7 @@ The password to be passed to the DBI constructor. Currently defaults to an empty
 AxKit::App::TABOO::Data->mk_classdata('dbstring');
 AxKit::App::TABOO::Data->mk_classdata('dbuser');
 AxKit::App::TABOO::Data->mk_classdata('dbpasswd');
-AxKit::App::TABOO::Data->mk_classdata('selectquery');
+AxKit::App::TABOO::Data->mk_classdata('dbfrom');
 AxKit::App::TABOO::Data->mk_classdata('dbtable');
 AxKit::App::TABOO::Data->mk_classdata('dbprimkey');
 AxKit::App::TABOO::Data->mk_classdata('elementorder');
@@ -399,7 +430,6 @@ Except for still being in alpha, and should have a few bugs, there is the issue
 
 Every load-type method should throw an exception or do something similar if it finds that the record it tries to retrieve doesn't exist. 
 
-I think I may have slightly misdesigned the Data classes, in that they are only designed to operate on one entry at a time. Probably, it is easy to fix this by adding plural versions of each data class, but I need to try to keep some independence from SQL syntax, and I haven't quite figured that out yet. 
 
 =head1 FORMALITIES
 
