@@ -14,13 +14,12 @@ use XML::LibXML;
 
 use vars qw/$NS/;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 NAME
 
 AxKit::App::TABOO::XSP::Story - News story management tag library for TABOO
 
-
 =head1 SYNOPSIS
 
 Add the story: namespace to your XSP C<<xsp:page>> tag, e.g.:
@@ -127,7 +126,7 @@ sub store : node({http://www.kjetil.kjernsmo.net/software/TABOO/NS/Story/Output}
 	delete $args{'auto-storyname'};
     }
     my $story = AxKit::App::TABOO::Data::Story->new();
-    $story->apache_request_data(\%args);
+    $story->populate(\%args);
 #    try {
 	$story->save($oldstorykey);
 #      }
@@ -168,7 +167,7 @@ sub this_story : struct {
       $args{'lasttimestamp'} = $timestamp->datetime;
     }
     my $story = AxKit::App::TABOO::Data::Story->new();
-    $story->apache_request_data(\%args);
+    $story->populate(\%args);
     $story->adduserinfo();
     $story->addcatinfo();
     
@@ -186,7 +185,7 @@ sub merge : struct attribOrChild(storyname,sectionid) {
 	my %args = $r->args;
 
     my $story = AxKit::App::TABOO::Data::Story->new();
-    $story->load('*', $attr_sectionid, $attr_storyname);
+    $story->load(what => '*', limit => (sectionid => $attr_sectionid, storyname=> $attr_storyname});
 
 
 
@@ -207,7 +206,7 @@ sub merge : struct attribOrChild(storyname,sectionid) {
 #        $args{'lasttimestamp'} = $timestamp->datetime;
 #      }
 #      my $story = AxKit::App::TABOO::Data::Story->new();
-#      $story->apache_request_data(\%args);
+#      $story->populate(\%args);
 #      $story->adduserinfo();
 #      $story->addcatinfo();
     
