@@ -14,7 +14,7 @@ use Data::Dumper;
 use vars qw/$NS/;
 
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 # Some constants
 # TODO: This stuff should go somewhere else!
@@ -35,7 +35,6 @@ use constant GOD       => 9;
 
 AxKit::App::TABOO::XSP::User - User information management and authorization tag library for TABOO
 
-
 =head1 SYNOPSIS
 
 Add the user: namespace to your XSP C<<xsp:page>> tag, e.g.:
@@ -110,7 +109,7 @@ sub store {
     }
     my $user = AxKit::App::TABOO::Data::User::Contributor->new();
     # Retrieve old data
-    $user->load($args{'username'});
+    $user->load(what => '*', limit => {'username' => $args{'username'}});
 
     if ($args{'username'} eq $editinguser) {
 	# It is the user editing his own data
@@ -153,7 +152,7 @@ sub store {
 	    }
 	}
     }
-    $user->apache_request_data(\%args);
+    $user->populate(\%args);
     $user->save();
 EOC
 }
@@ -183,7 +182,7 @@ sub new_user
         $args{'authlevel'} = 1;   
     }
     $args{'passwd'} = crypt($args{'passwd'}, AxKit::App::TABOO::XSP::User::makeSalt());
-    $user->apache_request_data(\%args);
+    $user->populate(\%args);
     AxKit::Debug(9, "Saving new user " . $args{'username'});
     $user->save();
 EOC
@@ -233,7 +232,7 @@ sub this_user : struct attribOrChild(username)
 {
     return << 'EOC';
     my $user = AxKit::App::TABOO::Data::User::Contributor->new();
-    $user->load($attr_username); 
+    $user->load(what => '*', limit => {'username' => $attr_username}); 
     my $doc = XML::LibXML::Document->new();
     my $root = $doc->createElementNS('http://www.kjetil.kjernsmo.net/software/TABOO/NS/User/Output', 'this-user');
     $doc->setDocumentElement($root);
